==> haskell-http-media-0.7.1.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-media.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-media
version: 0.7.1.1
id: http-media-0.7.1.1-IC7MqceKb34KNoeHVAAhLt
key: http-media-0.7.1.1-IC7MqceKb34KNoeHVAAhLt
license: MIT
copyright: (c) 2012-2017 Timothy Jones
maintainer: Timothy Jones <tim@zmthy.net>
homepage: https://github.com/zmthy/http-media
synopsis: Processing HTTP Content-Type and Accept headers
description:
    This library is intended to be a comprehensive solution to parsing and
    selecting quality-indexed values in HTTP headers.  It is capable of
    parsing both media types and language parameters from the Accept and
    Content header families, and can be extended to match against other
    accept headers as well.  Selecting the appropriate header value is
    achieved by comparing a list of server options against the
    quality-indexed values supplied by the client.
    .
    In the following example, the Accept header is parsed and then matched
    against a list of server options to serve the appropriate media using
    '\''mapAcceptMedia'\'':
    .
    > getHeader >>= maybe send406Error sendResourceWith . mapAcceptMedia
    >     [ ("text/html",        asHtml)
    >     , ("application/json", asJson)
    >     ]
    .
    Similarly, the Content-Type header can be used to produce a parser for
    request bodies based on the given content type with '\''mapContentMedia'\'':
    .
    > getContentType >>= maybe send415Error readRequestBodyWith . mapContentMedia
    >     [ ("application/json", parseJson)
    >     , ("text/plain",       parseText)
    >     ]
    .
    The API is agnostic to your choice of server.
category: Web
author: Timothy Jones
exposed: True
indefinite: False
exposed-modules:
    Network.HTTP.Media Network.HTTP.Media.Accept
    Network.HTTP.Media.Language Network.HTTP.Media.MediaType
    Network.HTTP.Media.RenderHeader
hidden-modules: Network.HTTP.Media.Language.Internal
                Network.HTTP.Media.MediaType.Internal Network.HTTP.Media.Quality
                Network.HTTP.Media.Utils
abi: abdbcaa8c84a0cc08fb3d417e69b3781
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/http-media-0.7.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/http-media-0.7.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/http-media-0.7.1.1
hs-libraries: HShttp-media-0.7.1.1-IC7MqceKb34KNoeHVAAhLt
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI containers-0.5.10.2
    utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=a56b20bddcd4f2f0090e82c4a91df92f
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=86282a526305f57509e4009ab924a497
haddock-interfaces: /usr/share/doc/haskell-http-media/html/http-media.haddock
haddock-html: /usr/share/doc/haskell-http-media/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-media-0.7.1.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-media.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-media
version: 0.7.1.1
id: http-media-0.7.1.1-7GtPrLmWejF6Fjt4ApRnO
key: http-media-0.7.1.1-7GtPrLmWejF6Fjt4ApRnO
license: MIT
copyright: (c) 2012-2017 Timothy Jones
maintainer: Timothy Jones <tim@zmthy.net>
homepage: https://github.com/zmthy/http-media
synopsis: Processing HTTP Content-Type and Accept headers
description:
    This library is intended to be a comprehensive solution to parsing and
    selecting quality-indexed values in HTTP headers.  It is capable of
    parsing both media types and language parameters from the Accept and
    Content header families, and can be extended to match against other
    accept headers as well.  Selecting the appropriate header value is
    achieved by comparing a list of server options against the
    quality-indexed values supplied by the client.
    .
    In the following example, the Accept header is parsed and then matched
    against a list of server options to serve the appropriate media using
    '\''mapAcceptMedia'\'':
    .
    > getHeader >>= maybe send406Error sendResourceWith . mapAcceptMedia
    >     [ ("text/html",        asHtml)
    >     , ("application/json", asJson)
    >     ]
    .
    Similarly, the Content-Type header can be used to produce a parser for
    request bodies based on the given content type with '\''mapContentMedia'\'':
    .
    > getContentType >>= maybe send415Error readRequestBodyWith . mapContentMedia
    >     [ ("application/json", parseJson)
    >     , ("text/plain",       parseText)
    >     ]
    .
    The API is agnostic to your choice of server.
category: Web
author: Timothy Jones
exposed: True
indefinite: False
exposed-modules:
    Network.HTTP.Media Network.HTTP.Media.Accept
    Network.HTTP.Media.Language Network.HTTP.Media.MediaType
    Network.HTTP.Media.RenderHeader
hidden-modules: Network.HTTP.Media.Language.Internal
                Network.HTTP.Media.MediaType.Internal Network.HTTP.Media.Quality
                Network.HTTP.Media.Utils
abi: f0f96a1455c9d9b6b1387e8574503c21
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/http-media-0.7.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/http-media-0.7.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/http-media-0.7.1.1
hs-libraries: HShttp-media-0.7.1.1-7GtPrLmWejF6Fjt4ApRnO
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.10-BoRVwnTiXXU9RJ6NEnu1BA
    containers-0.5.10.2 utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             case-insensitive-1.2.0.10-BoRVwnTiXXU9RJ6NEnu1BA=8d186fcd421d3c073314c1adeaca6740
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=e0ce70380190fd366eaf58242d407bf1
haddock-interfaces: /usr/share/doc/haskell-http-media/html/http-media.haddock
haddock-html: /usr/share/doc/haskell-http-media/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
